"use client"

import { useState, useEffect } from "react"
import Link from "next/link"
import { chapters } from "@/data/chapters"
import { notFound, useRouter } from "next/navigation"
import { ArrowLeft, BookOpen, CheckCircle, Clock, Search } from "lucide-react"
import type { Exercise } from "@/types/course"
import { getExercisesByChapter } from "@/services/exercise-service"

export default function ChapterExercisesPage({ params }: { params: { slug: string } }) {
  const router = useRouter()
  const [exercises, setExercises] = useState<Exercise[]>([])
  const [loading, setLoading] = useState(true)
  const [searchTerm, setSearchTerm] = useState("")
  const [chapter, setChapter] = useState(null)

  useEffect(() => {
    // Normalize the slug from URL
    const normalizedSlug = decodeURIComponent(params.slug).toLowerCase()
    console.log("URL slug:", normalizedSlug)

    // Find the chapter by comparing normalized slugs
    const foundChapter = chapters.find((c) => {
      const chapterTitle = c.chapter.split(". ")[1]
      const chapterSlug = chapterTitle
        .toLowerCase()
        .replace(/&/g, "et")
        .replace(/'/g, "-")
        .replace(/\s+/g, "-")
        .normalize("NFD")
        .replace(/[\u0300-\u036f]/g, "")
        .replace(/-+/g, "-")

      console.log(`Chapter "${chapterTitle}" -> normalized slug: "${chapterSlug}"`)

      return chapterSlug === normalizedSlug
    })

    setChapter(foundChapter)
  }, [params.slug])

  useEffect(() => {
    async function loadExercises() {
      if (chapter) {
        try {
          const data = await getExercisesByChapter(chapter.chapter)
          setExercises(data)
        } catch (error) {
          console.error("Erreur lors du chargement des exercices:", error)
        } finally {
          setLoading(false)
        }
      } else {
        setLoading(false)
      }
    }

    loadExercises()
  }, [chapter])

  const handleStartExercise = (exerciseId: string) => {
    router.push(`/exercices/${exerciseId}`)
  }

  const filteredExercises = exercises.filter(
    (exercise) =>
      exercise.title.toLowerCase().includes(searchTerm.toLowerCase()) ||
      exercise.description.toLowerCase().includes(searchTerm.toLowerCase()),
  )

  if (!chapter) {
    console.error(`Chapter not found for slug: ${params.slug}`)
    return notFound()
  }

  return (
    <div className="min-h-screen bg-gray-50">
      <div className={`py-12 px-4 ${chapter.color || "bg-blue-100"}`}>
        <div className="container mx-auto">
          <Link href={`/chapitres/${params.slug}`} className="flex items-center text-gray-700 mb-4 hover:underline">
            <ArrowLeft className="mr-2 h-4 w-4" />
            Retour au chapitre
          </Link>
          <h1 className="text-3xl font-bold text-gray-900 mb-2">Liste des exercices</h1>
          <p className="text-xl text-gray-800">Liste des exercices du chapitre: {chapter.chapter.split(". ")[1]}.</p>
        </div>
      </div>

      <div className="container mx-auto py-8 px-4">
        <div className="bg-white rounded-lg shadow-lg p-6 mb-8">
          <div className="relative">
            <div className="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
              <Search className="h-5 w-5 text-gray-400" />
            </div>
            <input
              type="text"
              placeholder="Rechercher un exercice..."
              value={searchTerm}
              onChange={(e) => setSearchTerm(e.target.value)}
              className="pl-10 pr-4 py-3 w-full border border-gray-300 rounded-lg focus:outline-none focus:ring-2 focus:ring-blue-500"
            />
          </div>
        </div>

        {loading ? (
          <div className="flex justify-center items-center h-64">
            <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-blue-500"></div>
          </div>
        ) : filteredExercises.length === 0 ? (
          <div className="bg-white rounded-lg shadow-md p-8 text-center">
            {searchTerm ? (
              <>
                <p className="text-gray-600 mb-4">Aucun exercice ne correspond à votre recherche "{searchTerm}".</p>
                <button
                  onClick={() => setSearchTerm("")}
                  className="bg-blue-600 hover:bg-blue-700 text-white py-2 px-6 rounded-lg inline-block"
                >
                  Effacer la recherche
                </button>
              </>
            ) : (
              <>
                <p className="text-gray-600 mb-4">Aucun exercice disponible pour ce chapitre.</p>
                <Link
                  href={`/chapitres/${params.slug}`}
                  className="bg-blue-600 hover:bg-blue-700 text-white py-2 px-6 rounded-lg inline-block"
                >
                  Retour au chapitre
                </Link>
              </>
            )}
          </div>
        ) : (
          <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
            {filteredExercises.map((exercise) => (
              <div
                key={exercise.id}
                className="bg-white rounded-lg shadow-lg overflow-hidden hover:shadow-xl transition-shadow"
              >
                <div className="p-6">
                  <div className="flex items-start mb-4">
                    <BookOpen className="h-6 w-6 text-blue-500 mr-3 mt-1" />
                    <div>
                      <h3 className="text-xl font-semibold">{exercise.title}</h3>
                      <p className="text-gray-600">{exercise.description}</p>
                    </div>
                  </div>

                  <div className="flex items-center justify-between text-sm text-gray-500 mb-6">
                    <div className="flex items-center">
                      <CheckCircle className="h-4 w-4 mr-1 text-green-500" />
                      <span>{exercise.questions.length} questions</span>
                    </div>
                    <div className="flex items-center">
                      <Clock className="h-4 w-4 mr-1 text-blue-500" />
                      <span>Durée estimée: {exercise.questions.length * 30} secondes</span>
                    </div>
                  </div>

                  <button
                    onClick={() => handleStartExercise(exercise.id)}
                    className="w-full bg-green-600 hover:bg-green-700 text-white py-3 px-4 rounded-lg font-medium flex items-center justify-center"
                  >
                    <CheckCircle className="h-5 w-5 mr-2" />
                    Commencer l'exercice
                  </button>
                </div>
              </div>
            ))}
          </div>
        )}
      </div>
    </div>
  )
}
